#!/usr/bin/env python
# coding: utf-8

# In[1]:


import pandas as pd
from itertools import combinations


# In[2]:


days_to_string = {
    1: "Mon",
    2: "Tue",
    4: "Wed",
    8: "Thu",
    16: "Fri",
    32: "Sat",
    64: "Sun"
}


# In[8]:


# TODO: transfrom to list comprehension
# comb for comb in combinations(lis, n) for n in range(1, len(lis)+1) if sum(comb) == dow
def find_dow(dow):
    lis = [1, 2, 4, 8, 16, 32, 64]
    for n in range(1, len(lis)+1):
        for comb in combinations(lis, n):
            try:
                if sum(comb) == int(dow):
                    return comb
            except:
                return None


# In[9]:


def get_dow(column):
    all_days = []
    d_list = [find_dow(val) for val in column]
    for item in d_list:
        d = ''            
        try:
            for i in item:
                if i == item[-1]:
                    d += (days_to_string[i])
                else:
                    d += (days_to_string[i] + ', ')

            all_days.append(d)

        except:
            d += 'NaN'
            all_days.append(d)

    return all_days




import codecs
import re

import setuptools

with codecs.open('bitmask_decoder/__init__.py', 'r', 'utf-8') as fd:
    version = re.search(r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]', fd.read(), re.MULTILINE).group(1)

if not version:
    raise RuntimeError('Cannot find version information')

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="bitmask-decoder",
    version=version,
    author="Stijn Maas",
    author_email="stijn_maas@live.nl",
    description="Python package to decode day-of-week bitmasks",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/RoelantDL/bitmask-decoder",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)